-- wTaskNoteFrame.lua: Sep 2010
-- Control and design of the list of notes frame

-- General design is going to be very similar to that of the current Blizzard quest frame
-- A tree in the left-hand pane, with the content of the note in the right-hand pane

-- Left-hand tree headers based on AceDB3 subtables: 
--   "global", "realm", "class", "race", "faction", "factionrealm", etc.
-- Global notes come first in the list, followed by current realm, current faction, current char
-- Probably won't use all of the available subtables, being able to share notes based on:
--   "global", "current realm", "current faction", "current char", "current profile" will be enough.
-- Design question is whether we want to allow one character to access another character's notes (probably yes)
-- If we go with global accessibility, then we only use the "global" level of AceDB, and we end up
-- with a larger amount of data loaded into memory.
--
-- Possible tree design
-- [+]Global
--   note1
--   note2
-- [+]Server 1
--   note4
--   note6
--   [+]Character 1
--     note7
--     note8
--   [+]Character 2
--     note3
--     note4
-- [+]Server 2
--   note9
--   note10
--   [+]Character 1
--     note11
--     note12
-- [+]User-Defined Category 1
--   note13
--   note14
--   note15
-- [+]User-Defined Category 2
--   note16
--   note17
--   note18
-- 
-- As we click on stuff in the left pane, we need to update the right pane to display the contents
-- Buttons: 
--   "New" (new note) 
--   "Delete" (delete selected note) 
--   "Move" (move a note to a different category, functionality might go on the edit frame instead)
--   "Copy" (make a copy of the currently selected note)
-- Note Attributes:
--   "category" (determines where in the tree it appears)
--   "subject" (short subject line)
--   "body" (body, not sure on length limit, probably same as a mail body)
--
-- It will probably make more sense that notes are always in "edit" mode.  In which case
-- we'll mostly just need a "Save" / "Undo" pair of buttons on the right side panel at the bottom.

-- Reference (creating a 2-panel layout design):
-- http://forums.wowace.com/showthread.php?t=13449
-- Anchor the first 2 controls to have full height and 1/2 the width each
-- Make the name unique to avoid clashes if another addon has a slightly different idea of what a 'Split' layout is
AceGUI:RegisterLayout("WTaskNote_Split",
	function(content, children)
		local width = content.width or content:GetWidth() or 0
		local height = content.height or content:GetHeight() or 0
		local controlWidth = width/2
		if children[1] and children[2] then
			children[1]:SetWidth(controlWidth)
			children[1]:SetHeight(height)
			children[1].frame:SetPoint("TOPLEFT",content,"TOPLEFT")
			children[1].frame:SetPoint("BOTTOMLEFT",content,"BOTTOMLEFT")
			children[1].frame:Show()
			
			children[2]:SetWidth(controlWidth)
			children[2]:SetHeight(height)
			children[2].frame:SetPoint("TOPLEFT",children[1],"TOPRIGHT")
			children[2].frame:SetPoint("BOTTOMLEFT",children[1],"BOTTOMRIGHT")
			children[2].frame:SetPoint("TOPRIGHT",content,"TOPRIGHT")
			children[2].frame:SetPoint("BOTTOMRIGHT",content,"BOTTOMRIGHT")
			children[2].frame:Show()
			safecall( content.obj.LayoutFinished, content.obj, nil, children[1].frame:GetHeight() )
		end
	end
)

-----------------------------------------------------------------------------
-- Create the main frame of the interface (for notes)
function WTaskNote:CreateNoteFrame()
	if wTaskNoteFrame then return end
	
	wTaskNoteFrame = AceGUI:Create("Frame")
	wTaskNoteFrame:SetTitle("Example Frame")
	wTaskNoteFrame:SetStatusText("AceGUI-3.0 Example Container Frame")
	wTaskNoteFrame:SetLayout("WTaskNote_Split")
	wTaskNoteFrame:SetWidth(600)
	wTaskNoteFrame:SetHeight(300)
	wTaskNoteFrame:SetCallback("OnClose", function(widget) widget:Hide() end)





end

function WTaskNote:ToggleNoteFrame()
	self.CreateNoteFrame()
	if WTaskNoteFrame:IsShown() then
--		HideUIPanel(WTaskNoteFrame)
	else
		wTaskNoteFrame:Show()
	end
end